@@ -1,6 +1,6 @@
 ************************************************************************
 * ISPACK FORTRAN SUBROUTINE LIBRARY FOR SCIENTIFIC COMPUTING
-* Copyright (C) 1998--2010 Keiichi Ishioka <ishioka@gfd-dennou.org>
+* Copyright (C) 1998--2011 Keiichi Ishioka <ishioka@gfd-dennou.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
@@ -140,7 +140,7 @@
         CALL SNKINI(MM,JC,3,IP,P,R,IP3,P3,R3)        
       END IF
 
-      CALL SOINIT(MM,IB,B)
+*      CALL SOINIT(MM,IB,B)
 
       DO L=1,LM
         CALL SNL2NM(L,N,M)
