@@ -1,6 +1,6 @@
 ************************************************************************
 * ISPACK FORTRAN SUBROUTINE LIBRARY FOR SCIENTIFIC COMPUTING
-* Copyright (C) 1998--2010 Keiichi Ishioka <ishioka@gfd-dennou.org>
+* Copyright (C) 1998--2011 Keiichi Ishioka <ishioka@gfd-dennou.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
@@ -18,15 +18,29 @@
 * 02110-1301 USA.
 ************************************************************************
 ************************************************************************
-*     INITIALIZATION OF LJPACK                                2010/01/28
+*     INITIALIZATION OF LJPACK                                2011/08/12
 *-----------------------------------------------------------------------      
-*          MM=0 ǤбǤ褦˽.
+*       MM=0 ǤбǤ褦˽.
+*       嵭νѤäΤǺƽ
+*       SSEѤAVXѤκݤ JMͤ󤬤뤳ȤΥåɲ
 *-----------------------------------------------------------------------
       SUBROUTINE LJINIT(MM,NM,JM,P,R)
 
       IMPLICIT REAL*8(A-H,O-Z)
       DIMENSION P(JM/2,MM+4),R((MM+1)*(2*NM-MM-1)+1)
 
+      CALL LJACHK(IA)
+
+      IF(IA.EQ.0) THEN
+        IF(MOD(JM,2).NE.0) CALL BSDMSG('E','LJINIT','JM must be even.')
+      ELSE IF(IA.EQ.1) THEN
+        IF(MOD(JM,4).NE.0) CALL BSDMSG('E','LJINIT',
+     &      'JM must be a multiple of 4 to use SSE.')
+      ELSE IF(IA.EQ.2) THEN
+        IF(MOD(JM,8).NE.0) CALL BSDMSG('E','LJINIT',
+     &      'JM must be a multiple of 8 to use AVX.')
+      END IF
+
       JH=JM/2
 
       CALL LJGAUS(JM,P(1,1),P(1,2))
@@ -38,7 +52,7 @@
 
 */ CALCULATION OF FUNCTION FOR RECURRENCE FORMULA /*
 
-      IF(MM.GE.0) THEN
+      IF(MM.GE.1) THEN
         M=1
         A=SQRT(1D0*(2*M+1)/(2*M))      
         DO J=1,JH
