@@ -1,6 +1,6 @@
 ************************************************************************
 * ISPACK FORTRAN SUBROUTINE LIBRARY FOR SCIENTIFIC COMPUTING
-* Copyright (C) 1998--2010 Keiichi Ishioka <ishioka@gfd-dennou.org>
+* Copyright (C) 1998--2011 Keiichi Ishioka <ishioka@gfd-dennou.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
@@ -19,6 +19,7 @@
 ************************************************************************
 ************************************************************************
 *     TRANSFORM SPECTRA TO GRID                               2009/08/11
+*        (sjpack-mpi б, JM=0 ξνɲ)     2011/08/30
 ************************************************************************
       SUBROUTINE SJTS2G(MM,NM,NN,IM,JM,S,G,IT,T,P,Q,R,WS,WG,W,IPOW)
 
@@ -28,6 +29,8 @@
       DIMENSION P(JM/2,MM+4),Q(JM/2,7),R(*)
       DIMENSION WS(2,0:NN),W(0:(JM+1)*(MM*2+1)-1),WG(0:IM-1)
 
+      IF(JM.EQ.0) RETURN
+
       CALL LJTSZG(NM,NN,JM,S,W(0),P,Q,R,WS,IPOW)
       DO M=1,MM
         NS=1+NN+1+(M-1)*(NN+NN+2-M)
